@@ -3,7 +3,7 @@
 ###################################################
 ### code chunk number 1: repair.Rnw:24-25
 ###################################################
-options(continue = " ", digits = 5)
+options(continue = "  ", digits = 5, max.print = 25, width = 70)
 
 
 ###################################################
